Wazimap
=======

Wazimap is a Django application for exploring census and other similar data. It makes it easy to understand a place
through the eyes of the data, and to explore data across a range of places. It is most suited for census data
but can easily be used with other data that is similarly focused on places in a country.

Check out `Wazimap South Africa <http://wazimap.co.za>`_ and `Wazimap Kenya <http://kenya.wazimap.org>`_ to
get an idea of what Wazimap is about.

Wazimap is a fork of the excellent `Censusreporter <https://censusreporter.org>`_ project which was funded by a
`Knight News Challenge grant <http://www.niemanlab.org/2012/10/knight-funding-expands-ires-journalist-friendly-census-site/>`_.
You can also find `Censusreporter on GitHub <https://github.com/censusreporter/censusreporter>`_.

Wazimap builds on Censusreporter and makes it easier to re-use. Wazimap was originally built by
`Code for South Africa <http://code4sa.org>`_ with the support of `Media Monitoring Africa <http://www.mediamonitoringafrica.org/>`_.
It is maintained by Code for South Africa.

* Wazimap is on GitHub at `github.com/Code4SA/wazimap <https://github.com/Code4SA/wazimap>`_.
* Wazimap is on Twitter as `@Wazimap <https://twitter.com/@Wazimap>`_.

Sites using Wazimap
===================

* `Wazimap South Africa <http://wazimap.co.za/>`_
* `Nepal Map <http://www.nepalmap.org>`_
* `Counting India <http://www.countingindia.com/>`_

License and Copyright
=====================

Copyright (c) 2014 Census Reporter

Wazimap is licensed under the MIT License.

The Wazimap name and branding is Copyright 2013-2017 Media Monitoring Africa (MMA) and may not be used without permission.

If you use this software, please provide attribution to Census Reporter, Wazimap, Media Monitoring Africa and Code for South Africa.

Contents
========

.. toctree::
   :maxdepth: 2

   started
   config
   geos
   data
   profiles
   customising
   deploying
   version_history


Indices and tables
==================

* :ref:`search`
